=============
madmom_models
=============

This repository is not usable without the `madmom
<https://github.com/CPJKU/madmom>`_ Python package. It contains model and data
files for some of the algorithms implemented with the ``madmom`` package.

Installation
============

Please install the `madmom <https://github.com/CPJKU/madmom>`_ package instead.
This repository is included as a Git submodule as the ``madmom/models/``
folder.

License
=======

All model and data files are distributed under the following license:

`Creative Commons Attribution-NonCommercial-ShareAlike 4.0
<http://creativecommons.org/licenses/by-nc-sa/4.0/legalcode>`_

The short version of this license is that you are free to:

**Share:**
  copy and redistribute the material in any medium or format

**Adapt:**
  remix, transform, and build upon the material

Under the following terms:

**Attribution:**
  You must give appropriate credit, provide a link to the license, and indicate
  if changes were made.
**NonCommercial:**
  You must not use the material for commercial purposes.
**ShareAlike:**
  If you remix, transform, or build upon the material, you must distribute your
  contributions under the same license as the original.

Data and model files usually have (but are not limited to) .npy, .npz, .h5,
.hdf5, .pkl or .mat file extensions.

If you want to include any of these files (or a variation or modification
thereof) or technology which utilises them in a commercial product, please
contact `Gerhard Widmer <http://www.cp.jku.at/people/widmer/>`_.

Note
====

Please note that pickled `madmom <https://github.com/CPJKU/madmom>`_
Processors using any of the files included in this repository inherit the
above license.
